PrecomputedTokenizerLoader
==========================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: PrecomputedTokenizerLoader
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~PrecomputedTokenizerLoader.__call__

   .. rubric:: Methods Documentation

   .. automethod:: __call__
